@@ -1,10 +1,10 @@
 #' @title Expected Error Rate
-#' @description Calculate expected OOB error rates based on random assignment 
-#'   and class sizes (prior).
+#' @description Calculate expected OOB error rates for randomForest 
+#'   classification model based on random assignment and class sizes (prior).
 #' 
-#' @param rf a \code{link{randomForest}} or \code{\link{rfPermute}} object.
+#' @param rf an object inheriting from \code{link{randomForest}}.
 #' 
-#' @return a vector of expected error rates.
+#' @return a vector of expected error rates for each class.
 #' 
 #' @author Eric Archer \email{eric.archer@@noaa.gov}
 #' 
@@ -14,6 +14,7 @@ exptd.err.rate <- function(rf) {
   if(!inherits(rf, "randomForest")) {
     stop("'rf' is not a randomForest or rfPermute object.")
   }
+  if(rf$type == "regression") stop("'rf' must be of a classification model")
   y.freq <- table(rf$y)
   exp.err <- 1 - y.freq / sum(y.freq)
   oob.err <- sum(exp.err * y.freq) / sum(y.freq)
